"""
Send e-mails about new events on your GitHub repositories

Do you want to receive e-mail notifications about new issues, pull requests,
and the like on your GitHub repositories?  Of course you do — but turning on
e-mail notifications in GitHub for repositories you're watching will mean you
get an e-mail for every comment on every issue, which is a bit too much.
``reponews`` aims for a happy medium: only e-mailing you about new issues and
similar activity on repositories of your choice.  Simply set it up to run under
cron or another job scheduler (sold separately) and you'll get periodic e-mails
listing new events.

Visit <https://github.com/jwodder/reponews> for more information.
"""

__version__ = "0.1.1"
__author__ = "John Thorvald Wodder II"
__author_email__ = "reponews@varonathe.org"
__license__ = "MIT"
__url__ = "https://github.com/jwodder/reponews"



from __future__ import annotations
import logging
from pathlib import Path
import re
from typing import TypeVar
from platformdirs import user_state_path

T = TypeVar("T")


log = logging.getLogger(__package__)


def mkalias(s: str) -> str:
    return s.replace("_", "-")


def get_default_state_file() -> Path:
    return user_state_path("reponews", "jwodder") / "state.json"


def dos2unix(s: str) -> str:
    return re.sub(r"\r\n?", "\n", s)


class NotFoundError(Exception):
    pass


class BogusEventError(Exception):
    pass


class UserError(Exception):
    pass
